from setuptools import setup


def readme():
    with open('README.md') as f:
        return f.read()


setup(name='connectpyse',
      version='0.4.2',
      description='A ConnectWise API tool for the rest of us.',
      long_description=readme(),
      classifiers=[
          'Development Status :: 3 - Alpha',
          'License :: OSI Approved :: MIT License',
          'Programming Language :: Python :: 3.5'
      ],
      keywords='connectwise rest api',
      url='https://github.com/markciecior/ConnectPyse',
      author='Joshua M Smith (original), Mark Ciecior (forked)',
      author_email='saether@gmail.com (original), mark@markciecior.com (forked)',
      license='MIT',
      packages=['.',
                'connectpyse.expense',
                'connectpyse.finance',
                'connectpyse.marketing',
                'connectpyse.procurement',
                'connectpyse.project',
                'connectpyse.sales',
                'connectpyse.schedule',
                'connectpyse.service',
                'connectpyse.system',
                'connectpyse.time'],
      py_modules = ['connectpyse.cw_controller',
                    'connectpyse.config',
                    'connectpyse.cw_model',
                    'connectpyse.restapi'],
      install_requires=[
          'requests'
      ],
      include_package_data=True,
      zip_safe=False)
